#include <pic18.h>
#include <peripheral/i2c.h>


/********************************************************************
*     Function Name:    EECurrentAddRead1                           *
*     Return Value:     error condition status or data byte         *
*     Parameters:       EE memory control byte with R/W set to 1    *
*     Description:      Reads data at current address of EE memory  *
*                       device. This routine can be used for any I2C*
*                       EE memory device, which only uses 1 byte of *
*                       address data as in the 24LC01B/02B/04B/08B. *
*                                                                   *  
********************************************************************/
#if defined (_I2C_V2) || defined (_I2C_V3) || defined (_I2C_V5) || defined (_I2C_V6)
unsigned int EECurrentAddRead1( unsigned char control )
{
  IdleI2C1();                      // ensure module is idle
  StartI2C1();                     // initiate START condition
  while ( SEN_x );      // wait until start condition is over 
  if ( BCL1IF )           // test for bus collision
    return ( -1 );                 // return with Bus Collision error 
  else
  {
    if ( WriteI2C1( control ) )    // write byte - R/W bit should be 0
    {
	  StopI2C1();  
      return ( -3 );               // set error for write collision
    }

    //IdleI2C1();                    // ensure module is idle
    if ( !ACKSTAT_x)   // test for ACK condition received
    { 
      RCEN_x = 1;       // enable master for 1 byte reception
      while ( RCEN_x ); // check that receive sequence is over
      NotAckI2C1();                // send NOT ACK condition
      while ( ACKEN_x );// wait until ACK sequence is over                        
      StopI2C1();                  // send STOP condition
      while ( PEN_x );  // wait until stop condition is over 
      if ( BCL1IF )       // test for bus collision
        return ( -1 );             // return with Bus Collision error 
    }
    else
    {
	  StopI2C1();  
      return ( -2 );               // return with Not Ack error condition
    }
  }
  return ( (unsigned int) SSP1BUF ); // return with contents of SSP1BUF
}

#endif
