#include <pic18.h>
#include <peripheral/i2c.h>


/*********************************************************************
*     Function Name:    putsI2C1                                     *
*     Return Value:     error condition status                       *
*     Parameters:       address of write string storage location     *
*     Description:      This routine writes a string to the I2C1 bus,*
*                       until a null character is reached. If Master *
*                       function putcI2C is called. When trans-      *
*                       mission is complete then test for ack-       *
*                       nowledge bit. If Slave transmitter wait for  *
*                       null character or not ACK received from bus  *
*                       device.                                      *
*********************************************************************/
#if defined (_I2C_V2) || defined (_I2C_V3) || defined (_I2C_V5) || defined (_I2C_V6) 
unsigned char putsI2C1( unsigned char *wrptr )
{
   unsigned char temp;  
	while ( *wrptr )                 // transmit data until null character 
  {
    if ( SSPM3_x )      // if Master transmitter then execute the following
    {
	  temp = putcI2C1 ( *wrptr );
	  if (temp ) return ( temp );   	
      //if ( putcI2C1( *wrptr ) )    // write 1 byte
      //{
      //  return ( -3 );             // return with write collision error
      //}
      //IdleI2C1();                  // test for idle condition
      //if ( ACKSTAT )  // test received ack bit state
      //{
      //  return ( -2 );             // bus device responded with  NOT ACK
      //}                            // terminate putsI2C1() function
    }

    else                           // else Slave transmitter
    {
      SSP1IF = 0;         // reset SSP1IF bit
      SSP1BUF = *wrptr;            // load SSP1BUF with new data
      CKP_x = 1;        // release clock line 
      while ( !SSP1IF );  // wait until ninth clock pulse received

      if ( ( !R_W_x) && ( !BF_x ) )// if R/W=0 and BF=0, NOT ACK was received
        return ( -2 );             // terminate PutsI2C1() function
    }
  wrptr ++;                        // increment pointer
  }                                // continue data writes until null character

  return ( 0 );
}
#endif
