#include <pic18.h>
#include <peripheral/i2c.h>


/*********************************************************************
*     Function Name:    EEAckPolling2                                *
*     Return Value:     error condition status                       *
*     Parameters:       EE memory control byte                       *
*     Description:      Acknowledge polling of I2C2 EE memory        *
*                       device. This routine can be used for most    *
*                       I2C EE memory devices which uses acknowledge *
*                       polling.                                     *
*********************************************************************/
#if defined (_I2C_V3) || defined (_I2C_V6)
unsigned char EEAckPolling2( unsigned char control )
{
  IdleI2C2();                      // ensure module is idle 
  StartI2C2();                     // initiate START condition
  while ( SEN2_x );      // wait until start condition is over 
  if ( BCL2IF )           // test for bus collision
    return ( -1 );                 // return with Bus Collision error 

  else
  {
    if ( WriteI2C2( control ) == -1)    // write byte - R/W bit should be 0
    {
	  StopI2C2();  
      return ( -3 );               // set error for write collision
    }

    while ( ACKSTAT2_x ) // test for ACK condition received
    {
      RestartI2C2();               // initiate Restart condition
      while ( RSEN2_x ); // wait until re-start condition is over 
      if ( BCL2IF )       // test for bus collision
        return ( -1 );             // return with Bus Collision error 

      if ( WriteI2C2( control ) == -1)  // write byte - R/W bit should be 0
      {
	    StopI2C2();  
        return ( -3 );             // set error for write collision
      }
    }
  } 
  
  StopI2C2();                      // send STOP condition
  while ( PEN2_x );      // wait until stop condition is over         
  if ( BCL2IF )           // test for bus collision
    return ( -1 );                 // return with Bus Collision error 
  return ( 0 );                    // return with no error     
}
#endif
