#include <pic18.h>
#include <peripheral/i2c.h>


/********************************************************************
*     Function Name:    getsI2C2                                    *
*     Return Value:     error condition status                      *
*     Parameters:       address of read string storage location     *
*                       length of string bytes to read              *
*     Description:      This routine reads a predetemined string    *
*                       length in from the I2C2 bus. The routine is *
*                       developed for the Master mode. The bus ACK  *
*                       condition is generated within this routine. *
********************************************************************/
#if defined (_I2C_V3) || defined (_I2C_V6)
unsigned char getsI2C2( unsigned char *rdptr, unsigned char length )
{
    while ( length -- )            // perform getcI2C2() for 'length' number of bytes
    {
      *rdptr++ = getcI2C2();       // save byte received
      while ( RCEN2_x ); // check that receive sequence is over    

      if ( BCL2IF )       // test for bus collision
        return ( -1 );             // return with Bus Collision error 

      if ( length )                // test if 'length' bytes have been read
      {
        ACKDT2_x = 0;    // set acknowledge bit state for ACK        
        ACKEN2_x = 1;    // initiate bus acknowledge sequence
        while ( ACKEN2_x ); // wait until ACK sequence is over 
      } 
    }
    return ( 0 );                  // last byte received so don't send ACK      
}
#endif
