#include <pic18.h>
#include <peripheral/i2c.h>


/********************************************************************
*     Function Name:    EEAckPolling                                *
*     Return Value:     error condition status                      *
*     Parameters:       EE memory control byte                      *
*     Description:      Acknowledge polling of I2C EE memory        *
*                       device. This routine can be used for most   *
*                       I2C EE memory device which uses acknowledge *
*                       polling.                                    *
********************************************************************/
#if defined (_I2C_V1) 
unsigned char EEAckPolling( unsigned char control )
{
  IdleI2C();                      // ensure module is idle 
  StartI2C();                     // initiate START condition
  while ( SEN_x );      // wait until start condition is over 
  if ( BCLIF )           // test for bus collision
    return ( -1 );                // return with Bus Collision error 

  else
  {
    if ( WriteI2C( control ) == -1)    // write byte - R/W bit should be 0
    {
	  StopI2C(); 
      return ( -3 );              // set error for write collision
    }

    while ( ACKSTAT_x) // test for ACK condition received
    {
      RestartI2C();               // initiate Restart condition
      while ( RSEN_x ); // wait until re-start condition is over 
      if ( BCLIF )       // test for bus collision
      {
        return ( -1 );            // return with Bus Collision error 
      }

      if ( WriteI2C( control ) == -1)  // write byte - R/W bit should be 0
      {
	    StopI2C(); 
        return ( -3 );            // set error for write collision
      }
    }
  }
         
  StopI2C();                      // send STOP condition
  while ( PEN_x );      // wait until stop condition is over         
  if ( BCLIF )           // test for bus collision
    return ( -1 );                // return with Bus Collision error 
  return ( 0 );                   // return with no error     
}
#endif
