#include <pic18.h>
#include <peripheral/i2c.h>


/********************************************************************
*     Function Name:    getsI2C                                     *
*     Return Value:     error condition status                      *
*     Parameters:       address of read string storage location     *
*                       length of string bytes to read              *
*     Description:      This routine reads a predetemined string    *
*                       length in from the I2C bus. The routine is  *                       
*                       developed for the Master mode. The bus ACK  *
*                       condition is generated within this routine. *
********************************************************************/
#if defined (_I2C_V1) 

unsigned char getsI2C( unsigned char *rdptr, unsigned char length )
{
    while ( length -- )           // perform getcI2C() for 'length' number of bytes
    {
      *rdptr++ = getcI2C();       // save byte received
      while ( RCEN_x ); // check that receive sequence is over    

      if ( BCLIF )       // test for bus collision
        return ( -1 );            // return with Bus Collision error

      if ( length )               // test if 'length' bytes have been read
      {
        ACKDT_x = 0;    // set acknowledge bit state for ACK        
        ACKEN_x = 1;    // initiate bus acknowledge sequence
        while ( ACKEN_x ); // wait until ACK sequence is over 
      } 
    }
    return ( 0 );                 // last byte received so don't send ACK      
}

#endif

